==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Input/wildmidi/translations/wildmidi_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>DecoderWildMidiFactory</name>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="50"/>
        <source>WildMidi Plugin</source>
        <translation>Engadido WildMidi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="55"/>
        <source>Midi Files</source>
        <translation>Ficheiros Midi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="109"/>
        <source>About WildMidi Audio Plugin</source>
        <translation>Sobre o engadido WildMidi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="110"/>
        <source>Qmmp WildMidi Audio Plugin</source>
        <translation>Engadido WildMidi do Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="111"/>
        <source>This plugin uses WildMidi library to play midi files</source>
        <translation>Este engadido usa a libraría WildMidi para reproducir ficheiros midi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="112"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>WildMidi Plugin Settings</source>
        <translation>Preferencias do engadido WildMidi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Instrument configuration: </source>
        <translation>Configuración dos instrumentos: </translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="43"/>
        <source>Sample rate:</source>
        <translation>Taxa de mostra:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="50"/>
        <source>Enhanced resampling</source>
        <translation>Remostraxe mellorada</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Reverberation</source>
        <translation>Reverberación</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="40"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
</context>
</TS>

==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/Input/wildmidi/translations/wildmidi_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>DecoderWildMidiFactory</name>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="49"/>
        <source>WildMidi Plugin</source>
        <translation>Engadido WildMidi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="54"/>
        <source>Midi Files</source>
        <translation>Ficheiros Midi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="106"/>
        <source>About WildMidi Audio Plugin</source>
        <translation>Sobre o engadido WildMidi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="107"/>
        <source>Qmmp WildMidi Audio Plugin</source>
        <translation>Engadido WildMidi do Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="108"/>
        <source>This plugin uses WildMidi library to play midi files</source>
        <translation>Este engadido usa a libraría WildMidi para reproducir ficheiros midi</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="109"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>WildMidi Plugin Settings</source>
        <translation>Preferencias do engadido WildMidi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Instrument configuration: </source>
        <translation>Configuración dos instrumentos: </translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="43"/>
        <source>Sample rate:</source>
        <translation>Taxa de mostra:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="50"/>
        <source>Enhanced resampling</source>
        <translation>Remostraxe mellorada</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Reverberation</source>
        <translation>Reverberación</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="40"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
</context>
</TS>
